@@ -4,11 +4,11 @@ This is a module that will install OS packages for you.
 
 
 from typing import List
-import subprocess
 import os
 
 from pydmt.utils.filesystem import unlink_files, mkdir_touch
 from pydmt.configs import ConfigSudo
+from pydmt.utils.subprocess import check_call
 
 from pydmt.api.one_source_one_target import OneSourceOneTarget
 
@@ -31,5 +31,5 @@ class BuilderApt(OneSourceOneTarget):
             'install',
         ])
         args.extend(self.packages)
-        subprocess.check_call(args)
+        check_call(args)
         mkdir_touch(self.target)
